#ifndef STRUCT_SETTINGS_DIR_H
#define STRUCT_SETTINGS_DIR_H

#define SNOWCP_CONF "snowcp.conf"
#define SNOWCP_CONF_VER "2"

// 最初はユーザーのホームのパスも入れようかと思ったけど止めた。
// g_getenvが返すのがconstってのと、使う予定がないのが理由。
typedef struct settings_dir
{
	char *config_dir;
	char *user_settings_dir;
	char *log_dir;
	char *compare_error_dir;
	char *compare_success_dir;
	int current_fd;
} SDir;

#endif
